# [Zope-tests] OK : Zope Buildbot / zopetoolkit-1.0_win-py2.4 slave-win

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Wed Feb 2 06:34:49 EST 2011

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.6 slave-osx
- Next message: [Zope-tests] OK : winbot / ztk_dev py_254_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zopetoolkit-1.0_win-py2.4 slave-win
    Build: http://dev.thehealthagency.com/buildbot/builders/zopetoolkit-1.0_win-py2.4%20slave-win/builds/103

    Build Reason: The web-page 'force build' button was pressed by '':

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Previous message: [Zope-tests] OK : Zope Buildbot / zopetoolkit-py2.6 slave-osx
- Next message: [Zope-tests] OK : winbot / ztk_dev py_254_win32
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list